pub enum AddError {
OverlapRange(OverlapError),
BadRange,
}Expand description
Possible errors when inserting a range to a DisjointRange.
Variants
OverlapRange(OverlapError)
Insertion erred because the range to insert overlaps with an existing
range in DisjointRange.
BadRange
Insertion failed because the provided parameters does not form a vaild range (e.g., when the start value is greater than the end value).